/*
**    $Id: handle.h,v 1.1 1993/06/26 22:08:15 pjs Exp $
**    Copyright (C) 1993  Patrick Sweeney
**
**    This program is free software; you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation; either version 2 of the License, or
**    any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program; if not, write to the Free Software
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
#ifndef _HANDLE_H_
#define _HANDLE_H_

#include "std.h"
#include "windows.h"

extern HANDLE handle_create(u8_t *p, u32_t nbytes, u32_t flags);
extern void handle_destroy(HANDLE h);
extern u8_t *handle_topointer(HANDLE h);
extern HANDLE handle_malloc(u32_t nbytes, u32_t flags);
extern u32_t handle_size(HANDLE h);
extern void handle_reset(HANDLE h, u8_t *p, u32_t nbytes);
extern void handle_decref(HANDLE h);
extern void handle_incref(HANDLE h);
extern u32_t handle_curref(HANDLE h);
extern bool_t handle_isvalid(HANDLE h);
extern u32_t handle_getflags(HANDLE h);
extern void handle_setflags(HANDLE h, u32_t flags);

#endif /* _HANDLE_H_ */
