/*
**    $Id: font.h,v 1.1 1993/06/28 03:07:20 pjs Exp $
**    Copyright (C) 1993  Patrick Sweeney
**
**    This program is free software; you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation; either version 2 of the License, or
**    any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program; if not, write to the Free Software
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
#ifndef _FONT_H_
#define _FONT_H_

#include "std.h"
#include "windows.h"
#include "color.h"

#define LF_FACESIZE 32

typedef struct
{
	short int lfHeight;
	short int lfWidth;
	short int lfEscapement;
	short int lfOrientation;
	short int lfWeight;
	BYTE lfItalic;
	BYTE lfUnderline;
	BYTE lfStrikeOut;
	BYTE lfCharSet;
	BYTE lfOutPrecision;
	BYTE lfClipPrecision;
	BYTE lfQuality;
	BYTE lfPitchAndFamily;
	BYTE lfFaceName[LF_FACESIZE];
} LOGFONT, *LPLOGFONT;

#endif /* _FONT_H_ */
