/*
**    $Id: std.h,v 1.1 1993/06/26 18:44:07 pjs Exp $
**    Copyright (C) 1993  Patrick Sweeney
**
**    This program is free software; you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation; either version 2 of the License, or
**    any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program; if not, write to the Free Software
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
#ifndef _STD_H_
#define _STD_H_

#include <sys/types.h>
#include <stdlib.h>

#define ALLOCN(T,N) (T *)malloc((size_t)sizeof(T)*(N))
#define ALLOC(T) ALLOCN(T,1)
#define RALLOCN(P,T,N) (T *)realloc((P), (size_t)sizeof(T)*(N))
#define ALLOCZN(T,N) (T *)calloc((size_t)(N), (size_t)sizeof(T))
#define ALLOCZ(T) ALLOCZN(T,1)
#define DEALLOC(P) free(P)

typedef unsigned long u32_t;
typedef long i32_t;
typedef unsigned short u16_t;
typedef short i16_t;
typedef unsigned char u8_t;
typedef char i8_t;
typedef char any_t;
typedef int bool_t;

#endif /* _STD_H_ */
