/*
**    $Id: cursor.h,v 1.1 1993/06/28 03:08:35 pjs Exp $
**    Copyright (C) 1993  Patrick Sweeney
**
**    This program is free software; you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation; either version 2 of the License, or
**    any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program; if not, write to the Free Software
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
#ifndef _CURSOR_H_
#define _CURSOR_H_

#include "windows.h"

typedef struct
{
	POINT pntHotSpot;
	WORD nWidth;
	WORD nHeight;
	WORD nWidthBytes;
	BYTE byPlanes;
	BYTE byBitsPix;
} CURSORICONINFO, FAR *LPCURSORICONINFO;

#endif /* _CURSOR_H_ */
