$(OBJDIR)/createrealbitmapindirect.o : createrealbitmapindirect.c /usr/local/src/wabi/DLL/h/windows.h \
  /usr/local/src/wabi/DLL/h/std.h /usr/local/src/wabi/DLL/h/bitmap.h /usr/local/src/wabi/DLL/h/color.h 
