/*
**    $Id: kern.c,v 1.1 1993/06/26 18:29:39 pjs Exp $
**    Copyright (C) 1993  Patrick Sweeney
**
**    This program is free software; you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation; either version 2 of the License, or
**    any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program; if not, write to the Free Software
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
/*
** The following code is for the kernel.exe
*/

/* Ordinal=113 */
__AHSHIFT()
{
	NOT_IMPLEMENTED();
}

/* Ordinal=114 */
__AHINCR()
{
	NOT_IMPLEMENTED();
}

/* Ordinal=173 */
__ROMBIOS()
{
	NOT_IMPLEMENTED();
}

/* Ordinal=174 */
__A000H()
{
	NOT_IMPLEMENTED();
}

/* Ordinal=178 */
__WINFLAGS()
{
	NOT_IMPLEMENTED();
}

/* Ordinal=179 */
__D000H()
{
	NOT_IMPLEMENTED();
}

/* Ordinal=181 */
__B000H()
{
	NOT_IMPLEMENTED();
}

/* Ordinal=182 */
__B800H()
{
	NOT_IMPLEMENTED();
}

/* Ordinal=183 */
__0000H()
{
	NOT_IMPLEMENTED();
}

/* Ordinal=190 */
__E000H()
{
	NOT_IMPLEMENTED();
}

/* Ordinal=193 */
__0040H()
{
	NOT_IMPLEMENTED();
}

/* Ordinal=194 */
__F000H()
{
	NOT_IMPLEMENTED();
}

/* Ordinal=195 */
__C000H()
{
	NOT_IMPLEMENTED();
}

