/*
**    $Id: brush.h,v 1.1 1993/06/28 03:06:32 pjs Exp $
**    Copyright (C) 1993  Patrick Sweeney
**
**    This program is free software; you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation; either version 2 of the License, or
**    any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program; if not, write to the Free Software
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
#ifndef _BRUSH_H_
#define _BRUSH_H_

#include "std.h"
#include "windows.h"
#include "color.h"

#define BS_SOLID	0
#define BS_NULL		1
#define BS_HOLLOW	1
#define BS_HATCHED	2
#define BS_PATTERN	3
#define BS_INDEXED	4
#define BS_DIBPATTERN	5

#define HS_HORIZONTAL	0
#define HS_VERTICAL	1
#define HS_FDIAGONAL	2
#define HS_BDIAGONAL	3
#define HS_CROSS	4
#define HS_DIAGCROSS	5

typedef struct
{
	WORD lbStyle;
	COLORREF lbColor;
	short int lbHatch;
} LOGBRUSH, *LPLOGBRUSH;

#endif /* _BRUSH_H_ */
